@@ -21,6 +21,7 @@ logger.setLevel(LOG_LEVEL)
 from sklearn.tree import _tree
 from dtreeviz.trees import dtreeviz
 
+
 def get_rules(tree, feature_names, class_names):
     tree_ = tree.tree_
     feature_name = [
@@ -30,9 +31,9 @@ def get_rules(tree, feature_names, class_names):
 
     paths = []
     path = []
-    
+
     def recurse(node, path, paths):
-        
+
         if tree_.feature[node] != _tree.TREE_UNDEFINED:
             name = feature_name[node]
             threshold = tree_.threshold[node]
@@ -44,32 +45,32 @@ def get_rules(tree, feature_names, class_names):
         else:
             path += [(tree_.value[node], tree_.n_node_samples[node])]
             paths += [path]
-            
+
     recurse(0, path, paths)
 
     # sort by samples count
     samples_count = [p[-1][1] for p in paths]
     ii = list(np.argsort(samples_count))
     paths = [paths[i] for i in reversed(ii)]
-    
+
     rules = []
     for path in paths:
         rule = "if "
-        
+
         for p in path[:-1]:
             if rule != "if ":
                 rule += " and "
             rule += str(p)
         rule += " then "
         if class_names is None:
-            rule += "response: "+str(np.round(path[-1][0][0][0],3))
+            rule += "response: " + str(np.round(path[-1][0][0][0], 3))
         else:
             classes = path[-1][0][0]
             l = np.argmax(classes)
             rule += f"class: {class_names[l]} (proba: {np.round(100.0*classes[l]/np.sum(classes),2)}%)"
         rule += f" | based on {path[-1][1]:,} samples"
         rules += [rule]
-        
+
     return rules
 
 
@@ -83,6 +84,7 @@ def save_rules(tree, feature_names, class_names, model_file_path, learner_name):
     except Exception as e:
         logger.info(f"Problem with extracting decision tree rules. {str(e)}")
 
+
 class DecisionTreeAlgorithm(SklearnAlgorithm):
 
     algorithm_name = "Decision Tree"
@@ -148,8 +150,9 @@ class DecisionTreeAlgorithm(SklearnAlgorithm):
         except Exception as e:
             logger.info(f"Problem when visualizing decision tree. {str(e)}")
 
-        save_rules(self.model, X_train.columns, class_names, model_file_path, learner_name)
-
+        save_rules(
+            self.model, X_train.columns, class_names, model_file_path, learner_name
+        )
 
 
 class DecisionTreeRegressorAlgorithm(SklearnAlgorithm):
