@@ -20,8 +20,9 @@ class AlgorithmFactory(object):
             raise AutoMLException(f"Cannot get algorithm class. {str(e)}")
 
     @classmethod
-    def load(cls, json_desc, model_file_path):
+    def load(cls, json_desc, learner_path, lazy_load):
         learner = AlgorithmFactory.get_algorithm(json_desc.get("params"))
-        learner.set_params(json_desc)
-        learner.load(model_file_path)
+        learner.set_params(json_desc, learner_path)
+        if not lazy_load:
+            learner.reload()
         return learner
