@@ -45,15 +45,11 @@ class RandomForestAlgorithm(SklearnTreesEnsembleClassifierAlgorithm):
             n_jobs=params.get("n_jobs", -1),
             random_state=params.get("seed", 1),
         )
-        if "max_steps" in params:
-            self.max_steps = params["max_steps"]
+        self.max_steps = self.params.get("max_steps", self.max_steps)
 
     def file_extension(self):
         return "random_forest"
 
-    def get_metric_name(self):
-        return "logloss"
-
 
 class RandomForestRegressorAlgorithm(SklearnTreesEnsembleRegressorAlgorithm):
 
@@ -81,13 +77,11 @@ class RandomForestRegressorAlgorithm(SklearnTreesEnsembleRegressorAlgorithm):
             n_jobs=params.get("n_jobs", -1),
             random_state=params.get("seed", 1),
         )
+        self.max_steps = self.params.get("max_steps", self.max_steps)
 
     def file_extension(self):
         return "random_forest"
 
-    def get_metric_name(self):
-        return "rmse"
-
 
 # For binary classification target should be 0, 1. There should be no NaNs in target.
 rf_params = {
