@@ -66,18 +66,27 @@ class SklearnAlgorithm(BaseAlgorithm):
 from supervised.utils.metric import Metric
 
 
-def predict_proba_function(estimator, X):
+def predict_proba_function_binary(estimator, X):
+    return estimator.predict_proba(X)[:, 1]
+
+
+def predict_proba_function_multiclass(estimator, X):
     return estimator.predict_proba(X)
 
 
 class SklearnTreesEnsembleClassifierAlgorithm(SklearnAlgorithm):
     def __init__(self, params):
         super(SklearnTreesEnsembleClassifierAlgorithm, self).__init__(params)
-        self.log_metric = Metric({"name": "logloss"})
+        self.log_metric = Metric(
+            {"name": self.params.get("eval_metric_name", "logloss")}
+        )
         self.max_iters = (
             1  # max iters is used by model_framework, max_steps is used internally
         )
-        self.predict_function = predict_proba_function
+        if params.get("ml_task") == BINARY_CLASSIFICATION:
+            self.predict_function = predict_proba_function_binary
+        else:
+            self.predict_function = predict_proba_function_multiclass
 
     def fit(
         self,
@@ -133,10 +142,6 @@ class SklearnTreesEnsembleClassifierAlgorithm(SklearnAlgorithm):
                     sample_weight=sample_weight_validation,
                 )
 
-                result["iteration"] += [e]
-                result["train"] += [tr]
-                result["validation"] += [vd]
-
                 if vd < min_val:  # optimize direction
                     min_val = vd
                     min_e = e
@@ -145,6 +150,10 @@ class SklearnTreesEnsembleClassifierAlgorithm(SklearnAlgorithm):
                     stop = True
                     break
 
+                result["iteration"] += [e]
+                result["train"] += [tr]
+                result["validation"] += [vd]
+
             # disable for now ...
             # if max_time is not None and time.time()-start_time > max_time:
             #    stop = True
@@ -155,7 +164,14 @@ class SklearnTreesEnsembleClassifierAlgorithm(SklearnAlgorithm):
             n_estimators = len(estimators)
 
         if log_to_file is not None:
-            pd.DataFrame(result).to_csv(log_to_file, index=False, header=False)
+            df_result = pd.DataFrame(result)
+            if self.log_metric.is_negative():
+                df_result["train"] *= -1.0
+                df_result["validation"] *= -1.0
+            df_result.to_csv(log_to_file, index=False, header=False)
+
+    def get_metric_name(self):
+        return self.params.get("eval_metric_name", "logloss")
 
 
 def predict_function(estimator, X):
@@ -165,5 +181,8 @@ def predict_function(estimator, X):
 class SklearnTreesEnsembleRegressorAlgorithm(SklearnTreesEnsembleClassifierAlgorithm):
     def __init__(self, params):
         super(SklearnTreesEnsembleRegressorAlgorithm, self).__init__(params)
-        self.log_metric = Metric({"name": "rmse"})
+        self.log_metric = Metric({"name": self.params.get("eval_metric_name", "rmse")})
         self.predict_function = predict_function
+
+    def get_metric_name(self):
+        return self.params.get("eval_metric_name", "rmse")
