@@ -7,6 +7,8 @@ import os
 import copy
 import logging
 import json
+import gc
+import sys
 
 from supervised.callbacks.callback_list import CallbackList
 from supervised.validation.validation_step import ValidationStep
@@ -113,6 +115,15 @@ class ModelFramework:
             y_validation_columns = preproces.prepare_target_labels(
                 y_validation_predicted
             ).columns.tolist()[:-1]
+        elif self._ml_task == BINARY_CLASSIFICATION:
+            class_names = self.preprocessings[-1].get_target_class_names()
+            y_validation_columns = "prediction"
+            if not ("0" in class_names and "1" in class_names):
+                y_validation_columns = (
+                    f"prediction_0_for_{class_names[0]}_1_for_{class_names[1]}"
+                )
+        else:
+            y_validation_columns = "prediction"
 
         return {
             "y_train_true": y_train_true,
@@ -277,6 +288,28 @@ class ModelFramework:
                 learner.model = None
                 # end of learner training
 
+                # clear data
+                del X_train
+                del y_train
+                del X_validation
+                del y_validation
+
+                if sample_weight is not None:
+                    del sample_weight
+                    del train_data["sample_weight"]
+                if sample_weight_validation is not None:
+                    del sample_weight_validation
+                    del validation_data["sample_weight"]
+
+                del train_data["X"]
+                del train_data["y"]
+                del validation_data["X"]
+                del validation_data["y"]
+                del train_data
+                del validation_data
+
+                gc.collect()
+
         # end of validation loop
         self.callbacks.on_framework_train_end()
         # self.get_additional_metrics()
@@ -320,7 +353,7 @@ class ModelFramework:
         self.oof_predictions = early_stopping.best_y_oof
 
         ###############################################################
-        # in case of Neural Network and one-hot coded multiclass target
+        # in case of one-hot coded multiclass target
         target_cols = [
             c for c in self.oof_predictions.columns.tolist() if "target" in c
         ]
@@ -413,7 +446,6 @@ class ModelFramework:
                 oof_preds = self.preprocessings[0].prepare_target_labels(
                     oof_predictions[prediction_cols].values
                 )
-
             else:
                 oof_preds = oof_predictions[prediction_cols]
 
@@ -448,6 +480,7 @@ class ModelFramework:
         with open(os.path.join(model_path, "framework.json"), "w") as fout:
             preprocessing = [p.to_json() for p in self.preprocessings]
             learners_params = [learner.get_params() for learner in self.learners]
+
             desc = {
                 "uid": self.uid,
                 "name": self._name,
@@ -463,6 +496,8 @@ class ModelFramework:
             }
             if self._threshold is not None:
                 desc["threshold"] = self._threshold
+            if self._single_prediction_time is not None:
+                desc["single_prediction_time"] = self._single_prediction_time
             fout.write(json.dumps(desc, indent=4))
 
         learning_curve_metric = self.learners[0].get_metric_name()
@@ -530,6 +565,9 @@ class ModelFramework:
         mf.final_loss = json_desc.get("final_loss", mf.final_loss)
         mf.metric_name = json_desc.get("metric_name", mf.metric_name)
         mf._is_stacked = json_desc.get("is_stacked", mf._is_stacked)
+        mf._single_prediction_time = json_desc.get(
+            "single_prediction_time", mf._single_prediction_time
+        )
         predictions_fname = json_desc.get("predictions_fname")
         if predictions_fname is not None:
             mf._oof_predictions_fname = os.path.join(results_path, predictions_fname)
