@@ -14,8 +14,18 @@ class EncodingSelector:
 
     @staticmethod
     def get(X, y, column):
-        unique_cnt = len(np.unique(X.loc[~pd.isnull(X[column]), column]))
+        # return PreprocessingCategorical.CONVERT_LOO
+        try:
+            unique_cnt = len(np.unique(X.loc[~pd.isnull(X[column]), column]))
+            if unique_cnt <= 20:
+                return PreprocessingCategorical.FEW_CATEGORIES
+        except Exception as e:
+            pass
+
+        return PreprocessingCategorical.MANY_CATEGORIES
+        """
         if unique_cnt <= 2 or unique_cnt > 25:
             return PreprocessingCategorical.CONVERT_INTEGER
 
         return PreprocessingCategorical.CONVERT_ONE_HOT
+        """
