@@ -35,6 +35,7 @@ from supervised.utils.config import LOG_LEVEL
 logger.setLevel(LOG_LEVEL)
 from supervised.utils.learning_curves import LearningCurves
 from supervised.utils.common import construct_learner_name, get_fold_repeat_cnt
+from supervised.utils.additional_plots import AdditionalPlots
 from tabulate import tabulate
 
 
@@ -42,6 +43,18 @@ class AdditionalMetrics:
     @staticmethod
     def binary_classification(target, predictions, sample_weight=None):
 
+        negative_label, positive_label = "0", "1"
+        mapping = None
+        try:
+            pred_col = predictions.columns[0]
+            if "_0_for_" in pred_col and "_1_for_" in pred_col:
+                t = pred_col.split("_0_for_")[1]
+                t = t.split("_1_for_")
+                negative_label, positive_label = t[0], t[1]
+                mapping = {0: negative_label, 1: positive_label}
+        except Exception as e:
+            pass
+
         predictions = np.array(predictions)
         sorted_predictions = np.sort(predictions)
         STEPS = 100  # can go lower for speed increase ???
@@ -138,21 +151,42 @@ class AdditionalMetrics:
 
         conf_matrix = pd.DataFrame(
             conf_matrix,
-            columns=["Predicted as negative", "Predicted as positive"],
-            index=["Labeled as negative", "Labeled as positive"],
+            columns=[
+                f"Predicted as {negative_label}",
+                f"Predicted as {positive_label}",
+            ],
+            index=[f"Labeled as {negative_label}", f"Labeled as {positive_label}"],
         )
 
+        predicted_labels = pd.Series((predictions.ravel() > threshold).astype(int))
+        predicted_probas = pd.DataFrame(
+            {
+                "proba_0": 1 - predictions.ravel(),
+                "proba_1": predictions.ravel(),
+            }
+        )
+
+        if mapping is not None:
+            labeled_target = target["target"].map(mapping)
+            predicted_labels = predicted_labels.map(mapping)
+        else:
+            labeled_target = target
+
         return {
             "metric_details": pd.DataFrame(details),
             "max_metrics": pd.DataFrame(max_metrics),
             "confusion_matrix": conf_matrix,
             "threshold": threshold,
+            "additional_plots": AdditionalPlots.plots_binary(
+                labeled_target, predicted_labels, predicted_probas
+            ),
         }
 
     @staticmethod
     def multiclass_classification(target, predictions, sample_weight=None):
         all_labels = [i[11:] for i in predictions.columns.tolist()[:-1]]
 
+        predicted_probas = predictions[predictions.columns[:-1]]
         ll = logloss(
             target, predictions[predictions.columns[:-1]], sample_weight=sample_weight
         )
@@ -171,6 +205,7 @@ class AdditionalMetrics:
             target = pd.DataFrame({"target": t})
 
         # Print the confusion matrix
+        predicted_labels = predictions["label"]
         predictions = predictions["label"]
         if not pd.api.types.is_string_dtype(predictions):
             predictions = predictions.astype(str)
@@ -200,6 +235,9 @@ class AdditionalMetrics:
         return {
             "max_metrics": pd.DataFrame(max_metrics).transpose(),
             "confusion_matrix": conf_matrix,
+            "additional_plots": AdditionalPlots.plots_multiclass(
+                target, predicted_labels, predicted_probas
+            ),
         }
 
     @staticmethod
@@ -223,7 +261,8 @@ class AdditionalMetrics:
                     "Metric": list(max_metrics.keys()),
                     "Score": list(max_metrics.values()),
                 }
-            )
+            ),
+            "additional_plots": AdditionalPlots.plots_regression(target, predictions),
         }
 
     @staticmethod
@@ -275,7 +314,7 @@ class AdditionalMetrics:
         confusion_matrix = additional_metrics["confusion_matrix"]
         threshold = additional_metrics["threshold"]
 
-        with open(os.path.join(model_path, "README.md"), "w") as fout:
+        with open(os.path.join(model_path, "README.md"), "w", encoding="utf-8") as fout:
             fout.write(model_desc)
             fout.write("\n## Metric details\n{}\n\n".format(max_metrics.to_markdown()))
             fout.write(
@@ -289,10 +328,16 @@ class AdditionalMetrics:
             AdditionalMetrics.add_permutation_importance(
                 fout, model_path, fold_cnt, repeat_cnt
             )
+
+            plots = additional_metrics.get("additional_plots")
+            if plots is not None:
+                AdditionalPlots.append(fout, model_path, plots)
+
             AdditionalMetrics.add_shap_importance(
                 fout, model_path, fold_cnt, repeat_cnt
             )
             AdditionalMetrics.add_shap_binary(fout, model_path, fold_cnt, repeat_cnt)
+
             fout.write("\n\n[<< Go back](../README.md)\n")
 
     @staticmethod
@@ -302,7 +347,7 @@ class AdditionalMetrics:
         max_metrics = additional_metrics["max_metrics"].transpose()
         confusion_matrix = additional_metrics["confusion_matrix"]
 
-        with open(os.path.join(model_path, "README.md"), "w") as fout:
+        with open(os.path.join(model_path, "README.md"), "w", encoding="utf-8") as fout:
             fout.write(model_desc)
             fout.write("\n### Metric details\n{}\n\n".format(max_metrics.to_markdown()))
             fout.write(
@@ -314,12 +359,18 @@ class AdditionalMetrics:
             AdditionalMetrics.add_permutation_importance(
                 fout, model_path, fold_cnt, repeat_cnt
             )
+
+            plots = additional_metrics.get("additional_plots")
+            if plots is not None:
+                AdditionalPlots.append(fout, model_path, plots)
+
             AdditionalMetrics.add_shap_importance(
                 fout, model_path, fold_cnt, repeat_cnt
             )
             AdditionalMetrics.add_shap_multiclass(
                 fout, model_path, fold_cnt, repeat_cnt
             )
+
             fout.write("\n\n[<< Go back](../README.md)\n")
 
     @staticmethod
@@ -327,7 +378,7 @@ class AdditionalMetrics:
         additional_metrics, model_desc, model_path, fold_cnt, repeat_cnt
     ):
         max_metrics = additional_metrics["max_metrics"]
-        with open(os.path.join(model_path, "README.md"), "w") as fout:
+        with open(os.path.join(model_path, "README.md"), "w", encoding="utf-8") as fout:
             fout.write(model_desc)
             fout.write(
                 "\n### Metric details:\n{}\n\n".format(
@@ -340,12 +391,18 @@ class AdditionalMetrics:
             AdditionalMetrics.add_permutation_importance(
                 fout, model_path, fold_cnt, repeat_cnt
             )
+
+            plots = additional_metrics.get("additional_plots")
+            if plots is not None:
+                AdditionalPlots.append(fout, model_path, plots)
+
             AdditionalMetrics.add_shap_importance(
                 fout, model_path, fold_cnt, repeat_cnt
             )
             AdditionalMetrics.add_shap_regression(
                 fout, model_path, fold_cnt, repeat_cnt
             )
+
             fout.write("\n\n[<< Go back](../README.md)\n")
 
     @staticmethod
